---
title: <span class="badge builder"></span> ExemplarConfig
---
# <span class="badge builder"></span> ExemplarConfig

## Constructor

```python
ExemplarConfig()
```
## Methods

### <span class="badge object-method"></span> build

Builds the object.

```python
def build() -> heatmap.ExemplarConfig
```

### <span class="badge object-method"></span> color

Sets the color of the exemplar markers

```python
def color(color: str) -> typing.Self
```

## See also

 * <span class="badge object-type-class"></span> [ExemplarConfig](./object-ExemplarConfig.md)
